#!/usr/bin/python
# -*- coding: utf-8 -*-

# thumbor imaging service
# https://github.com/thumbor/thumbor/wiki

# Licensed under the MIT license:
# http://www.opensource.org/licenses/mit-license
# Copyright (c) 2011 globo.com thumbor@googlegroups.com


import thumbor.filters
from thumbor.filters import BaseFilter, filter_method

# A Thumbor filter that resizes the image while allowing it to be less than the
# provided request height and width, but always keeping the aspect ratio.


class Filter(BaseFilter):
  phase = thumbor.filters.PHASE_AFTER_LOAD

  @filter_method()
  async def keep_ratio(self):
    target_width = self.context.request.width
    target_height = self.context.request.height

    source_width, source_height = self.context.request.engine.size
    source_aspect_ratio = float(source_width) / float(source_height)

    if source_width < target_width:
      self.context.request.width = source_width
      self.context.request.height = source_height * source_aspect_ratio
    elif source_height < target_height:
      self.context.request.width = source_width / source_aspect_ratio
      self.context.request.height = source_height



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages
from thumbor_filter_keep_ratio import __version__

setup(
    name='thumbor_filter_keep_ratio',
    version=__version__,
    description='A filter for Thumbor for resizing keeping aspect ratio',
    long_description='''
A Thumbor filter that resizes the image while allowing it to be less than the
provided request height and width, but always keeping the aspect ratio.
''',
    keywords='thumbor filter',
    author='single.dk',
    author_email='dev@single.dk',
    url='https://github.com/babelhq/thumbor-filter-keep-ratio',
    license='MIT',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Operating System :: MacOS',
        'Operating System :: POSIX',
        'Operating System :: Unix',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.7',
    ],
    packages=find_packages(),
    include_package_data=True,
)



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import logging

__version__ = '0.0.2'

try:
    from thumbor_filter_keep_ratio.keep_ratio import Filter
except ImportError:
    logging.exception('Could not import thumbor_filter_keep_ratio. Probably due to setup.py installing it.')
